Module: GettextSetup
- Defined in:
- lib/gettext-setup/pot.rb,
lib/gettext-setup/metadata_pot.rb,
lib/gettext-setup/gettext_setup.rb
Defined Under Namespace
Modules: MetadataPot, Pot Classes: NoConfigFoundError
Class Method Summary collapse
- .add_repository_to_chain(project_name, options) ⇒ Object
-
.candidate_locales ⇒ Object
Returns the locale for the current machine.
- .clear ⇒ Object
- .config ⇒ Object
- .config? ⇒ Boolean
- .default_locale ⇒ Object
- .default_locale=(new_locale) ⇒ Object
-
.initialize(locales_path = 'locales', options = {}) ⇒ Object
locales_pathshould include: - config.yaml - a .pot file for the project - i18n directories for languages, each with a .po file - if using .mo files, an LC_MESSAGES dir in each language dir, with the .mo file in it validoptionsfields: :file_format - one of the supported backends for fast_gettext (e.g. :po, :mo, :yaml, etc.). -
.initialize_config(locales_path = 'locales') ⇒ Object
Sets up the config class variables.
- .locales ⇒ Object
- .locales_path ⇒ Object
-
.negotiate_locale(accept_header) ⇒ Object
Given an HTTP Accept-Language header return the locale with the highest priority from it for which we have a locale available.
-
.negotiate_locale!(accept_header) ⇒ Object
Negotiates and sets the locale based on an accept language header.
- .translation_repositories ⇒ Object
Class Method Details
.add_repository_to_chain(project_name, options) ⇒ Object
65 66 67 68 69 70 71 |
# File 'lib/gettext-setup/gettext_setup.rb', line 65 def self.add_repository_to_chain(project_name, ) repository = FastGettext::TranslationRepository.build(project_name, path: locales_path, type: [:file_format] || :po, ignore_fuzzy: false) @translation_repositories[project_name] = repository unless @translation_repositories.key? project_name end |
.candidate_locales ⇒ Object
Returns the locale for the current machine. This is most useful for shell applications that need an ACCEPT-LANGUAGE header set.
97 98 99 |
# File 'lib/gettext-setup/gettext_setup.rb', line 97 def self.candidate_locales Locale.candidates(type: :cldr).join(',') end |
.clear ⇒ Object
101 102 103 |
# File 'lib/gettext-setup/gettext_setup.rb', line 101 def self.clear Locale.clear end |
.config ⇒ Object
77 78 79 |
# File 'lib/gettext-setup/gettext_setup.rb', line 77 def self.config @config ||= {} end |
.config? ⇒ Boolean
59 60 61 62 63 |
# File 'lib/gettext-setup/gettext_setup.rb', line 59 def self.config? raise NoConfigFoundError, File.join(locales_path, 'config.yaml') unless @config @config end |
.default_locale ⇒ Object
85 86 87 |
# File 'lib/gettext-setup/gettext_setup.rb', line 85 def self.default_locale config['default_locale'] || 'en' end |
.default_locale=(new_locale) ⇒ Object
89 90 91 92 93 |
# File 'lib/gettext-setup/gettext_setup.rb', line 89 def self.default_locale=(new_locale) FastGettext.default_locale = new_locale Locale.set_default(new_locale) config['default_locale'] = new_locale end |
.initialize(locales_path = 'locales', options = {}) ⇒ Object
locales_path should include:
-
config.yaml
-
a .pot file for the project
-
i18n directories for languages, each with a .po file
-
if using .mo files, an LC_MESSAGES dir in each language dir, with the .mo file in it
valid options fields: :file_format - one of the supported backends for fast_gettext (e.g. :po, :mo, :yaml, etc.)
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/gettext-setup/gettext_setup.rb', line 22 def self.initialize(locales_path = 'locales', = {}) GettextSetup.initialize_config(locales_path) # Make the translation methods available everywhere Object.send(:include, FastGettext::Translation) # Define our text domain, and set the path into our root. I would prefer to # have something smarter, but we really want this up earlier even than our # config loading happens so that errors there can be translated. add_repository_to_chain(config['project_name'], ) # 'chain' is the only available multi-domain type in fast_gettext 1.1.0 We should consider # investigating 'merge' once we can bump our dependency FastGettext.add_text_domain('master_domain', type: :chain, chain: @translation_repositories.values) FastGettext.default_text_domain = 'master_domain' # Likewise, be explicit in our default language choice. Available locales # must be set prior to setting the default_locale since default locale must # available. FastGettext.default_available_locales = (FastGettext.default_available_locales || []) | locales FastGettext.default_locale = default_locale Locale.set_default(default_locale) end |
.initialize_config(locales_path = 'locales') ⇒ Object
Sets up the config class variables.
Call this without calling initialize when you only need to deal with the translation files and you don’t need runtime translation.
51 52 53 54 55 56 57 |
# File 'lib/gettext-setup/gettext_setup.rb', line 51 def self.initialize_config(locales_path = 'locales') config_path = File.absolute_path('config.yaml', locales_path) File.exist?(config_path) || raise(NoConfigFoundError, config_path) @config = YAML.load_file(config_path)['gettext'] @locales_path = locales_path end |
.locales ⇒ Object
105 106 107 108 109 110 |
# File 'lib/gettext-setup/gettext_setup.rb', line 105 def self.locales explicit = Dir.glob(File.absolute_path('*/*.po', locales_path)).map do |x| File.basename(File.dirname(x)) end ([default_locale] + explicit).uniq end |
.locales_path ⇒ Object
73 74 75 |
# File 'lib/gettext-setup/gettext_setup.rb', line 73 def self.locales_path @locales_path ||= File.join(Dir.pwd, 'locales') end |
.negotiate_locale(accept_header) ⇒ Object
Given an HTTP Accept-Language header return the locale with the highest priority from it for which we have a locale available. If none exists, return the default locale
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/gettext-setup/gettext_setup.rb', line 115 def self.negotiate_locale(accept_header) unless @config raise ArgumentError, 'No config.yaml found! Use ' \ '`GettextSetup.initialize(locales_path)` to locate your config.yaml' end return FastGettext.default_locale if accept_header.nil? available_locales = accept_header.split(',').map do |locale| pair = locale.strip.split(';q=') pair << '1.0' unless pair.size == 2 # Ignore everything but the language itself; that means that we treat # 'de' and 'de-DE' identical, and would use the 'de' message catalog # for both. pair[0] = pair[0].split('-')[0] pair[0] = FastGettext.default_locale if pair[0] == '*' pair end.sort_by do |(_, qvalue)| -1 * qvalue.to_f end.select do |(locale, _)| FastGettext.available_locales.include?(locale) end if available_locales && available_locales.first available_locales.first.first else # We can't satisfy the request preference. Just use the default locale. default_locale end end |
.negotiate_locale!(accept_header) ⇒ Object
Negotiates and sets the locale based on an accept language header.
145 146 147 |
# File 'lib/gettext-setup/gettext_setup.rb', line 145 def self.negotiate_locale!(accept_header) FastGettext.locale = negotiate_locale(accept_header) end |
.translation_repositories ⇒ Object
81 82 83 |
# File 'lib/gettext-setup/gettext_setup.rb', line 81 def self.translation_repositories @translation_repositories end |